.. currentmodule:: message_ix.tools.sankey

:mod:`.sankey`: generate Sankey diagrams
****************************************

See :meth:`.Reporter.add_sankey` and the :file:`westeros_sankey.ipynb` :ref:`tutorial <tutorial-westeros>`.

API reference
=============

.. automodule:: message_ix.tools.sankey
   :members:
